Boost: current_function.hpp documentation

| # current_function.hpp

The header `<boost/current_function.hpp>` defines a single macro, `BOOST_CURRENT_FUNCTION`, similar to the C99 predefined identifier `__func__`.

`BOOST_CURRENT_FUNCTION` expands to a string literal containing the (fully qualified, if possible) name of the enclosing function. If there is no enclosing function, the behavior is undefined.

Some compilers do not provide a way to obtain the name of the current enclosing function. On such compilers, `BOOST_CURRENT_FUNCTION` expands to `"(unknown)"`.

Copyright © 2002 by Peter Dimov. Distributed under the Boost Software License, Version 1.0. See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt.